@@ -32,7 +32,7 @@ FILE_FORMATS = {
     },
     'Other': {
         '.json', '.torrent', '.zip', '.rar',
-        '.7z', '.torrent', '.psd', 'pdf',
+        '.7z', '.torrent', '.psd', '.pdf',
     }
 }
 
@@ -111,15 +111,18 @@ async def write_last_post_file(file: Path, url: str):
 async def check_direct(url: URL):
     mapping_direct = ['i.pixl.is', r's..putmega.com', r's..putme.ga', r'img-...cyberdrop...', r'f.cyberdrop...',
                       r'fs-...cyberdrop...', r'i.bunkr...', r'i..bunkr...', r'i...bunkr...', r'media-files.bunkr...',
-                      r'media-files..bunkr...', r'jpg.church/images/...', r'simp..jpg.church']
+                      r'media-files..bunkr...', r'cdn.bunkr...', r'cdn..bunkr...', r'cdn...bunkr...',
+                      r'jpg.church/images/...', r'simp..jpg.church']
     return any(re.search(domain, url.host) for domain in mapping_direct)
 
 
 async def create_config(config: Path, passed_args=None, remake=None):
     if config.is_file() and not remake:
+        await log("Validating Config")
         await validate_config(config)
         return
 
+    await log("Creating Config File")
     config_data = config_default
     if passed_args:
         for arg in authentication_args:
@@ -168,7 +171,7 @@ async def validate_config(config: Path):
     except KeyError:
         config.unlink()
         await log("Config was malformed, recreating.")
-        await create_config(config)
+        await create_config(config, None, True)
 
 
 async def run_args(config: Path, cmd_arg: Dict):
@@ -178,6 +181,7 @@ async def run_args(config: Path, cmd_arg: Dict):
     if data['Apply_Config']:
         return data
 
+    await log("Gathering Args")
     config_data = config_default[0]["Configuration"]
     for arg in authentication_args:
         if arg in cmd_arg.keys():
