@@ -40,14 +40,14 @@ class KemonoCrawler:
             title = title + " (Kemono.party)"
             results = []
 
-            posts = soup.select("a[class=fancy-link]")
+            posts = soup.select('article[class="post-card post-card--preview"] a')
             for post in posts:
                 path = post.get('href')
                 if path:
                     post_link = URL("https://kemono.party" + path)
                     results.extend(await self.parse_post(session, post_link, title))
 
-            next_page = soup.select_one('a[title="Next page"]')
+            next_page = soup.select_one('a[class=next]')
             if next_page:
                 next_page = next_page.get('href')
                 if next_page:
